==> django_userena_ce-7.0.2.tar.gz: django_userena_ce-7.0.2/README.md <==
# Django Userena (Community Edition)

[![Build Status](https://github.com/django-userena-ce/django-userena-ce/workflows/CI/badge.svg?branch=main)](https://github.com/django-userena-ce/django-userena-ce/actions?query=workflow%3ACI+branch%3Amain)
[![PyPI version](https://badge.fury.io/py/django-userena-ce.svg)](https://badge.fury.io/py/django-userena-ce)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/django-userena-ce)](https://pypi.org/project/django-userena-ce/)
[![Coverage Status](https://coveralls.io/repos/github/django-userena-ce/django-userena-ce/badge.svg?branch=main)](https://coveralls.io/github/django-userena-ce/django-userena-ce?branch=main)
[![Documentation Status](https://img.shields.io/badge/docs-passing-4a4c4c1.svg)](https://django-userena-ce.github.io/django-userena-ce/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

This project is a community edition fork of
[django-userena](https://github.com/bread-and-pepper/django-userena).

Userena is a Django application that supplies your Django project with full
account management. It's a fully customizable application that takes care of
the signup, activation, messaging and more. It's BSD licensed, which means you
can use it commercially for free!

## Supported Software

Software | Versions
---|---
Python | 3.7, 3.8, 3.9, 3.10, 3.11
Django | 3.2, 4.0, 4.1
Django Guardian | \>2.0

## [Documentation](https://django-userena-ce.github.io/django-userena-ce/index.html)

Complete documentation about the
[installation](https://django-userena-ce.github.io/django-userena-ce/installation.html),
[settings](https://django-userena-ce.github.io/django-userena-ce/settings.html) and
[F.A.Q.](https://django-userena-ce.github.io/django-userena-ce/faq.html) is available on
[All Documentation](https://django-userena-ce.github.io/django-userena-ce/index.html).

For list of updates and changes see `HISTORY.md` file.

==> django_userena_ce-7.0.3.tar.gz: django_userena_ce-7.0.3/README.md <==
# Django Userena (Community Edition)

[![Build Status](https://github.com/django-userena-ce/django-userena-ce/workflows/CI/badge.svg?branch=main)](https://github.com/django-userena-ce/django-userena-ce/actions?query=workflow%3ACI+branch%3Amain)
[![PyPI version](https://badge.fury.io/py/django-userena-ce.svg)](https://badge.fury.io/py/django-userena-ce)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/django-userena-ce)](https://pypi.org/project/django-userena-ce/)
[![Coverage Status](https://coveralls.io/repos/github/django-userena-ce/django-userena-ce/badge.svg?branch=main)](https://coveralls.io/github/django-userena-ce/django-userena-ce?branch=main)
[![Documentation Status](https://img.shields.io/badge/docs-passing-4a4c4c1.svg)](https://django-userena-ce.github.io/django-userena-ce/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)

This project is a community edition fork of
[django-userena](https://github.com/bread-and-pepper/django-userena).

Userena is a Django application that supplies your Django project with full
account management. It's a fully customizable application that takes care of
the signup, activation, messaging and more. It's BSD licensed, which means you
can use it commercially for free!

## Supported Software

Software | Versions
---|---
Python | 3.8, 3.9, 3.10, 3.11
Django | 3.2, 4.1, 4.2
Django Guardian | \>2.0

## [Documentation](https://django-userena-ce.github.io/django-userena-ce/index.html)

Complete documentation about the
[installation](https://django-userena-ce.github.io/django-userena-ce/installation.html),
[settings](https://django-userena-ce.github.io/django-userena-ce/settings.html) and
[F.A.Q.](https://django-userena-ce.github.io/django-userena-ce/faq.html) is available on
[All Documentation](https://django-userena-ce.github.io/django-userena-ce/index.html).

For list of updates and changes see `HISTORY.md` file.
